@@ -10,7 +10,7 @@
 
 #' @details This function conducts variation partitioning and hierarchical partitioning to calculate the unique, shared (referred as to "common") and independent contributions of each predictor (or matrix) to explained variation (R-squared) on canonical analysis (RDA,CCA and db-RDA).
 #' Variation partitioning should be the starting point prior to hierarchical partitioning. While the former emphasizes unique and common variation among predictors, the latter emphasizes the overall importance of each predictor (or group of predictors). This function synchronously implements variation and hierarchical partitioning for single- and multiple-response models without limits in the number of predictors / matrices of predictors. 
-#' This package were particularly inspired by the very popular paper by Chevan & Sutherland (1991), R package "yhat" (Nimon, Oswald & Roberts 2013) and "hier.part"(Walsh & Mac Nally 2013).
+#' This package were particularly inspired by the very popular paper by Chevan & Sutherland (1991), R package "yhat" (Nimon, Oswald & Roberts 2013) and "hier.part"(Walsh & Mac Nally 2013). At this stage, although our internal function \code{\link{Canonical.Rsq}} can calculate R-squared of adjusted R-squared of CCA, it takes a long time. In order to save calculation time, we still have to call \code{\link{cca}} and \code{\link{RsquareAdj}} functions for CCA in vegan.
 
 #' @return a list containing
 #' @return \item{Method_Type}{The type of canonical analysis and the type of total explained variation.}
@@ -88,7 +88,10 @@ return(newlist)
 if(is.data.frame(iv))
 {
   if(sum(is.na(dv))>=1|sum(is.na(iv))>=1)
-  {cat("Error: NA is not allowed in this analysis")}
+  {stop("NA is not allowed in this analysis")}
+  if(nrow(iv)<=ncol(iv))
+  {stop("sample size (row) is less than the number of predictors")}
+
   else
   {method <- method[1]
   type <- type[1]
@@ -271,10 +274,10 @@ else
 #{rdacca.mhp(dv, iv,method,type,trace,plot.perc)}
 {nvar  <-  length(iv)
   if(sum(unlist(lapply(iv,is.data.frame)))<nvar)
-  stop("Error: data.frame is required for each group explanatory table")
+  stop("data.frame is required for each group explanatory table")
 
   if(sum(is.na(dv))>=1|sum(is.na(unlist(iv)))>=1)
-  {cat("Error: NA is not allowed in this analysis")}
+  {stop("NA is not allowed in this analysis")}
   
   else
   {method <- method[1]
@@ -504,4 +507,3 @@ return(outputList)
 }
 }
 }
-
